@@ -29,7 +29,7 @@
 #define SIZEOF_VOIDP 8
 #define SIZEOF_FLOAT 4
 #define SIZEOF_DOUBLE 8
-#define SIZEOF_TIME_T 4
+#define SIZEOF_TIME_T 8
 #define PRI_LL_PREFIX "ll"
 #define rb_pid_t pid_t
 #define PIDT2NUM(v) INT2NUM(v)
@@ -44,9 +44,9 @@
 #define NUM2GIDT(v) NUM2UINT(v)
 #define PRI_GIDT_PREFIX PRI_INT_PREFIX
 #define rb_time_t time_t
-#define TIMET2NUM(v) INT2NUM(v)
-#define NUM2TIMET(v) NUM2INT(v)
-#define PRI_TIMET_PREFIX PRI_INT_PREFIX
+#define TIMET2NUM(v) LL2NUM(v)
+#define NUM2TIMET(v) NUM2LL(v)
+#define PRI_TIMET_PREFIX PRI_LL_PREFIX
 #define rb_dev_t dev_t
 #define DEVT2NUM(v) INT2NUM(v)
 #define NUM2DEVT(v) NUM2INT(v)
@@ -119,6 +119,7 @@
 #define HAVE_STRUCT_STAT_ST_CTIM 1
 #define HAVE_STRUCT_STAT_ST_CTIMESPEC 1
 #define HAVE_STRUCT_STAT_ST_CTIMENSEC 1
+#define HAVE_STRUCT_TIMEVAL 1
 #define HAVE_STRUCT_TIMESPEC 1
 #define HAVE_STRUCT_TIMEZONE 1
 #define HAVE_CLOCKID_T 1
@@ -145,7 +146,6 @@
 #define SIZEOF_UINTPTR_T 8
 #define HAVE_SSIZE_T 1
 #define SIZEOF_SSIZE_T 8
-#define GC_MARK_STACKFRAME_WORD 78
 #define GETGROUPS_T gid_t
 #define RETSIGTYPE void
 #define HAVE_ALLOCA 1
@@ -194,6 +194,7 @@
 #define HAVE_READLINK 1
 #define HAVE_READDIR_R 1
 #define HAVE_FSYNC 1
+#define HAVE_FDATASYNC 1
 #define HAVE_FCHOWN 1
 #define HAVE_SETITIMER 1
 #define HAVE_SETEUID 1
@@ -245,6 +246,7 @@
 #define HAVE_CLOCK_GETTIME 1
 #define HAVE_GETTIMEOFDAY 1
 #define HAVE_POLL 1
+#define HAVE_PPOLL 1
 #define HAVE_PREAD 1
 #define HAVE_SHUTDOWN 1
 #define HAVE_SIGALTSTACK 1
@@ -261,7 +263,7 @@
 #define RSHIFT(x,y) ((x)>>(int)(y))
 #define FILE_COUNT _r
 #define FILE_READPTR _p
-#define SIZEOF_STRUCT_STAT_ST_INO 4
+#define SIZEOF_STRUCT_STAT_ST_INO SIZEOF_LONG
 #define HAVE__SC_CLK_TCK 1
 #define STACK_GROW_DIRECTION -1
 #define _REENTRANT 1
@@ -277,6 +279,7 @@
 #define USE_ELF 1
 #define DLEXT_MAXLEN 3
 #define DLEXT ".so"
+#define LIBDIR_BASENAME "lib"
 #define HAVE_PTHREAD_H 1
 #define RUBY_LIB_VERSION_STYLE 3	/* full */
 #define RUBY_EXEC_PREFIX "/usr/local"
